<?php

namespace app\index\Controller;

use think\Db;
use think\View;
use think\Controller;
use think\Request;
use common\Codeinfo;
use common\Tools;
use app\common\model\User;

class Wap extends Controller
{
    /**
     * 数据库对象
     */
    private $db;
    private $config;
    public function __construct()
    {
        $this->config = json_decode(file_get_contents(APP_PATH . 'config.json'), true)['system'];
    }
    public function index(Request $par)
    {
        $params = $par->param();
        switch ($params['m']) {
            case 'album':
                return $this->album($params['c']);
                break;
            case 'video':
                return $this->video($params['c'], $params['v']);
                break;
            case 'more':
                return $this->more($params['c']);
                break;
            case 'share':
                return $this->share($params['c']);
                break;
            default:
                # code...
                break;
        }
    }
    private function share($vid)
    {
        if (!$vid) {
            abort(404, '不存在的分享数据');
            die;
        }
        $data = db::view('share', 'shareid,user,fid,createTime')
            ->view('filelist', 'filename,type', ['filelist.fid=share.fid', 'filelist.user=share.user'])
            //->view('filecount', ['shareid' => 'mssid'], 'filecount.fid=share.fid')
            ->view('user', 'avatar,username,sign', 'user.id=share.user')
            ->where('share.shareid', $vid)
            ->find();
        if (!$data) {
            abort(404, '不存在的分享数据');
            die;
        }
        if (empty($data['avatar'])) {
            $data['avatar'] = "/model/static/img/default-avatar.jpg";
        }
        $data['uptime'] = Tools::tranTime($data['createTime']);
        $data['enid'] = $vid;
        $otherData = db::view('share', 'shareid')
            ->view('filelist', 'filename,type', ['filelist.fid=share.fid', 'filelist.user=share.user'])
            ->view('filecount', ['ssid', 'path', 'duration'], 'filecount.fid=filelist.fid')
            ->view('server', 'playhost', 'server.ssid=filecount.ssid')
            ->where('share.shareid', 'neq', $vid)
            ->where('filecount.filetype', 'video')
            ->limit(10)
            ->select();
        $user = new User;
        $user->isLogin();
        $result = $user->done();
        if ($result['status']) {
            $avatar = $result['avatar'];
        } else {
            $avatar = $user->avatar;
        }
        $view = new View;
        $view->type = 'share';
        $view->aid = $vid;
        $view->data = $data;
        $view->items = $otherData;
        $view->avatar = $avatar;
        $view->model = 'share';
        $view->webname = $this->config['webname'];
        return $view->fetch('video');
    }
    private function more($user)
    {
        $udb = db::name('user')->find($user);
        if (!$udb) {
            return json(Codeinfo::FAILD);
        }
        $albums = db::name('album')->where('user', $udb['id'])->page(1, 20)->order('time desc')->select();
        $view = new View;
        $view->albums = $albums;
        $view->udb = $udb;
        $view->webname = $this->config['webname'];
        return $view->fetch('morealbum');
    }
    private function album($enid)
    {
        $album = db::view('album')
            ->view('user', 'avatar,nickname', 'user.id=album.user')
            ->find($enid);
        if (!$album) {
            return json(Codeinfo::FAILD);
            die;
        }
        $album['content'] = json_decode($album['content']);
        $items = db::view('filelist', 'filename,type,user')
            ->view('filecount', 'path,duration,fid', 'filecount.fid=filelist.fid')
            ->view('server', 'playhost', 'server.ssid=filecount.ssid')
            ->view('share', 'shareid', ['share.fid=filelist.fid'])
            ->view('statistics', 'num', ['statistics.aid="' . $enid . '"', 'statistics.vid=filelist.fid'], 'LEFT')
            ->view('FileSale', 'price', ['FileSale.fid=filelist.fid', 'FileSale.user=filelist.user'], 'LEFT')
            ->view('usersetting', 'content', ['usersetting.uid=filelist.user', 'usersetting.type="score"'], 'LEFT')
            ->where('filelist.id', 'in', $album['content'])
            ->where('filelist.user', 'in', (isset($this->webconfig['publicoff']) && $this->webconfig['publicoff'] === 1) ? [$album['user'], 1] : [$album['user']])
            ->where('filelist.type', 'video')
            ->select();
        foreach ($items as $key => $value) {
            if ($value['duration']) {
                $time_arr = explode(':', $value['duration']);
                if ($time_arr[0] == "00") {
                    $items[$key]['duration'] = "{$time_arr[1]}:{$time_arr[2]}";
                }
            }
            // if (!$price = db::name('share')->where('fid', $value['fid'])->where('user', $album['user'])->field('shareid')->find()) {
            //     $items[$key]['price'] = 0;
            //     $items[$key]['shareid'] = 0;
            // } else {
            //     $items[$key]['shareid'] = $price['shareid'];
            //     $items[$key]['price'] = $price['price'];
            // }
        }
        $view = new View;
        $view->type = 'album';
        $view->album = $album;
        $view->items = $items;
        $view->enid = $enid;
        $view->webname = $this->config['webname'];
        return $view->fetch('album');
    }
    private function video($aid, $fid)
    {
        $data = db::view('album', 'user,enid,content')
            ->view('filelist', 'filename,fid,uptime', 'filelist.user=album.user')
            ->view('user', 'avatar,nickname,username,sign', 'user.id=album.user')
            ->where('filelist.fid', $fid)
            ->find($aid);
        if (!$data) {
            return json(Codeinfo::FAILD);
        }
        $data['uptime'] = Tools::tranTime($data['uptime']);
        $ids = json_decode($data['content'], true);
        $items = db::view('filelist', 'id,filename,fid')
            ->view('filecount', 'path', 'filecount.fid=filelist.fid')
            ->view('server', 'playhost', 'server.ssid=filecount.ssid')
            ->where('id', 'in', $ids)
            ->select();
        $user = new User;
        $user->isLogin();
        $result = $user->done();
        if ($result['status']) {
            $avatar = $result['avatar'];
        } else {
            $avatar = $user->avatar;
        }
        $view = new View;
        $view->avatar = $avatar;
        $view->data = $data;
        $view->items = $items;
        $view->model = 'album';
        $view->type = 'album';
        $view->aid = $data['enid'];
        $view->webname = $this->config['webname'];
        return $view->fetch('video');
    }
}
