<?php

namespace app\common\model;

use think\Model;
use think\Db;
use think\Session;
use think\Config;
use think\Cookie;
use common\Tools;
use common\Codeinfo;
use common\Sign;
use PHPMailer\SendEmail;
use think\Cache;

class User extends Model
{
    protected $pk = 'id';
    public $uid;
    /**
     * 定义全局用户ID
     */
    public $username;
    /**
     * 定义全局用户 @str
     */
    public $passrod;
    /**
     * 定义用户密码 @str
     */
    private $config;
    /**
     * 读取系统配置 @object
     */
    private $dirhash;
    /**
     * 读取系统目录混淆密文 @str
     */
    public $avatar = '/model/static/img/default-avatar.jpg';
    /**
     * 定义默认头像
     */
    private $msg;
    /**
     * 状态管理
     */
    private $ssid;
    /**
     * SESSION_ID @str
     */
    public $extend;
    /**
     * 推广参数
     */
    private $db;
    /**
     * 数据库对象 @object
     */
    private $token = [
        "iss" => "",
        "aud" => "",
        "iat" => '',
        "nbf" => '',
        "exp" => '',
        "user" => []
    ];
    private $key = '';
    public function __construct($params = [])
    {
        $this->config = json_decode(file_get_contents(APP_PATH . 'config.json'), true)['system'];
        $this->dirhash = config('system.dirhash');
        $this->ssid = session_id();
        $this->db = Db::name('user');
        $this->token['iat'] = time();
        $this->token['nbf'] = time();
        $this->token['exp'] = time() + $this->config['timeout'];
        $this->key = config::get('system.loginToken');
        Cookie::init(['prefix' => 'cp_', 'expire' => $this->config['timeout'], 'path' => '/']);
    }
    public function emailReg()
    {
        if (!$this->ssid) {
            return $this->msg = Codeinfo::SESSIONFAILD;
        } else {
            $randpass = mt_rand(10000000, 99999999);
            if (SendEmail::SendEmail($this->config['webname'] . '-注册提示', '您的密码是:' . $randpass, $this->username)) {
                $ify = array(
                    'user' => $this->username,
                    'password' => $randpass,
                );
                $this->extend ? $ify['extend'] = $this->extend : '';
                Cache::set($this->ssid . 'ify', $ify, 1800);
                return $this->msg = Codeinfo::EMAILSUCCESS;
            } else {
                return $this->msg = Codeinfo::EMAILFAILD;
            }
        }
    }
    public function createUser()
    {
        $salt = Tools::only(time());
        $userhash = md5('/' . config('system.dirhash') . $this->username);
        $userdata = [
            'enid' => Tools::only(time() * 1000),
            'username' => $this->username,
            'password' => md5($this->password . $salt),
            'salt' => $salt,
            'phone' => '',
            'nickname' => '游客',
            'avatar' => $this->avatar,
            'status' => $this->config['isVerify'] == 1 ? 0 : 1,
            'hash' => $userhash,
            'diskspace' => $this->config['defaultspace'],
            'score' => 0,
            'sign' => '他很懒什么也没留下...',
            'alipay' => '',
            'createtime' => date('Y-m-d H:i:s', time())
        ];
        $uid = $this->db->insertGetId($userdata);
        if (!$uid) {
            return $this->msg = Codeinfo::CREATEMASTERDIRFAILD;
        }
        $filedirDB = [
            'hash' => $userhash,
            'fromHash' => '',
            'fromPath' => '',
            'path' => '/',
            'user' => $uid,
            'filename' => '',
            'type' => 'dir',
            'size' => '-',
            'deserver' => 'all',
            'dborder' => 99,
            'uptime' => date('Y-m-d H:i:s', time())
        ];
        $file = db::name('filelist')->insert($filedirDB);
        if (!$file) {
            return $this->msg = Codeinfo::CREATEMASTERDIRFAILD;
        } else {
            if ($this->extend) {
                $exconfig = db::name('syssetting')->find('markketing');
                $exconfig = json_decode($exconfig['content']);
                if ($exuser = $this->db->where('enid', $this->params->extend)->find()) {
                    $exadd = [
                        'masteruser' => $exuser['id'],
                        'fromuser' => $uid,
                        'uptime' => date('Y-m-d H:i:s', time())
                    ];
                    db::name('userext')->insert($exadd);
                    $this->db->where('id', $exuser['id'])->setInc('score', $exconfig->onereward);
                    db::name('userextlog')->insert(
                        [
                            'muser' => $exuser['id'],
                            'fuser' => $uid,
                            'content' => '一级推广',
                            'score' => $exconfig->onereward,
                            'time' => date('Y-m-d H:i:s', time())
                        ]
                    );
                    if ($fromuser = db::name('userext')->where('fromuser', $exuser['id'])->find()) {
                        $this->db->where('id', $fromuser['masteruser'])->setInc('score', $exconfig->tworeward);
                        db::name('userextlog')
                            ->insert(
                                [
                                    'muser' => $fromuser['masteruser'],
                                    'fuser' => $uid,
                                    'content' => '二级推广',
                                    'score' => $exconfig->tworeward,
                                    'time' => date('Y-m-d H:i:s', time())
                                ]
                            );
                    }
                }
            }
            switch ($this->config['isVerify']) {
                case 0:
                    $this->msg = Codeinfo::REGSUCCESS;
                    break;
                case 1:
                    $this->msg = Codeinfo::USERSTATUS0;
            }
            return;
        }
    }
    public function resetPass()
    {
        if ($udb = $this->db->where('username', $this->username)->find()) {
            $randpass = mt_rand(10000000, 99999999);
            if (SendEmail::SendEmail($this->config['webname'] . '-密码修改', '您的新密码是:' . $randpass, $this->username)) {
                $ify = array(
                    'user' => $this->username,
                    'password' => $randpass
                );
                Cache::set(session_id() . 'modify', $ify, 1800);
                return $this->msg = Codeinfo::EMAILSUCCESS;
            } else {
                return $this->msg = Codeinfo::EMAILFAILD;
            }
        } else {
            return $this->msg = Codeinfo::NOUSER;
        }
    }
    public function isLogin()
    {
        if (!Session::has('user', 'index') || empty(Cookie::get('token'))) {
            return $this->msg = Codeinfo::NOLOGIN;
            die;
        }
        $checkSign = new Sign();
        $detoken = $checkSign->decode(Cookie::get('token'), Config('system.loginToken'), ['HS256']);
        if (!$detoken || gettype($detoken) != 'object') {
            return $this->msg = Codeinfo::TOKENFAILD;
            die;
        }
        if (Session::get('user.username', 'index') != $detoken->user->username) {
            return $this->msg = Codeinfo::TOKENFAILD;
            die;
        }
        if ($this->config['weboff'] === 1) {
            return $this->msg = Codeinfo::WEBOFF;
        } else {
            if ($udb = db::name('user')->where('username', $detoken->user->username)->find()) {
                if ($udb['status'] == 1) {
                    $USERCACHE = Cache::get('usercache' . $detoken->user->id);
                    $msg['count'] = Tools::formatBytes($USERCACHE['disksize']);
                    $msg['space'] = Tools::formatBytes($udb['diskspace']);
                    $msg['pro'] = $USERCACHE['diskpro'];
                    $msg['info'] = 'SUCCESS';
                    $msg['isLogin'] = true;
                    $msg['status'] = true;
                    $checkSign = new Sign();
                    $this->token['user'] = $udb;
                    Cookie::set('token', $checkSign->encode($this->token, $this->key));
                    $this->token['user']['avatar'] ? $this->token['user']['avatar'] : $this->token['user']['avatar'] = '/model/static/img/default-avatar.jpg';
                    $this->msg = $this->token['user'];
                    $this->msg['status'] = true;
                    return $this->msg['info'] = $msg;
                } else {
                    switch ($udb['status']) {
                        case 0:
                            return $this->msg = Codeinfo::USERSTATUS0;
                            break;
                        case 1:
                            return $this->msg = Codeinfo::USERSTATUS1;
                            break;
                        case 3:
                            return $this->msg = Codeinfo::USERSTATUS3;
                            break;
                        case 4:
                            return $this->msg = Codeinfo::USERSTATUS4;
                            break;
                    }
                }
            } else {
                return $this->msg = Codeinfo::NOUSER;
            }
        }
    }
    public function buyFile($file)
    {
        $udb = $this->db->find($this->uid);
    }
    /**
     * 需要传递FID参数 并 声明全局 UID
     * @STR
     */
    public function isBuy($fid)
    {
        $file = db::name('buylog')->where('fid', $fid)->where('uid', $this->uid)->find();
        if (!$file) {
            return $this->msg = false;
        } else {
            return $this->msg = true;
        }
    }
    public function done()
    {
        return $this->msg;
    }
}
